////////////////////////////////////////////////////////////////////////////////
//Name:         convert.c                                                      /
//Last rev:     2002/12/13                                                     /
//Description:  ASCII hex <> binary conversion functions                       /
////////////////////////////////////////////////////////////////////////////////
//Taylor Electronics Services (TES)                                            /
//                                                                             /
//  This source code is public domain.                                         /
////////////////////////////////////////////////////////////////////////////////
//hextobin(hex1,hex2)                                                          /
//ascii hex to 8 bit integer conversion                                        /
////////////////////////////////////////////////////////////////////////////////
//input     hex1        first half (msb) ascii hex character                   /
//          hex2        second half ascii hex character                        /
//                                                                             /
//output    (return)    binary 8 bits                                          /
////////////////////////////////////////////////////////////////////////////////
//case is don't care, non hex characters give ?? results                       /
//-----------------------------------------------------------------------------/
//                                          //call example:                    /
//int8 asciidata1;                                                             /
//int8 asciidata2;                                                             /
//int8 rawbinary;                                                              /
//                                                                             /
//asciidata1='A';                           //msb,'A' or 'a'                   /
//asciidata2='7';                           //lsb                              /
//rawbinary=hex2bin(asciidata1,asciidata2); //return is 0xa7                   /
////////////////////////////////////////////////////////////////////////////////
unsigned int8 hextobin(unsigned int8 * hex1,unsigned int8 * hex2){

unsigned int8 result;

result=hex1;                                //get upper half
swap(result);                               //move to high nibble
result=result & 0xf0;                       //trim bits

if (bit_test(hex1,6))                       //if was A-F or a-f then adjust
    result=result+0x90;
result=result+(hex2 & 0x0f);                //get low nibble
if (bit_test(hex2,6))                       //if was A-F or a-f then adjust
    result=result+0x09;
return result;
}

////////////////////////////////////////////////////////////////////////////////
//bintohex(bin,hexarray)                                                       /
//8 bit integer to ascii hex conversion                                        /
////////////////////////////////////////////////////////////////////////////////
//input     bin         binary value to convert                                /
//          hexarray    destination for ascii hex result                       /
//                                                                             /
//output    hexarray    hexarray[0]=msb, hexarray[1]=lsb                       /
////////////////////////////////////////////////////////////////////////////////
//case returned is all upper, array must be min 2 elements                     /
//-----------------------------------------------------------------------------/
//                                          //call example:                    /
//int8 rawbinary;                                                              /
//int8 asciidata[2];                                                           /
//                                                                             /
//rawbinary=0xa7;                                                              /
//bin2hex(rawbinary,asciidata);                                                /
//putc(asciidata[0]);                       //msb = 'A'                        /
//putc(asciidata[1]);                       //lsb = '7'                        /
////////////////////////////////////////////////////////////////////////////////
void bintohex(unsigned int8 * bindat,unsigned int8 * hexarray){

unsigned int8 temp;

temp=bindat & 0xf0;                         //first half
temp=swap(temp);
temp=temp+0x30;
if (temp>0x39)
    temp=temp+0x07;                         //if A-F then adjust
hexarray[0]=temp;
temp=(bindat & 0x0f)+0x30;
if (temp>0x39)
    temp=temp+0x07;
hexarray[1]=temp;

return;
}
////////////////////////////////////////////////////////////////////////////////
